scipy.sparse.extract
====================

.. automodule:: scipy.sparse.extract

   
   
   .. rubric:: Functions

   .. autosummary::
   
      find
      tril
      triu
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      coo_matrix
   
   

   
   
   